@@ -50,6 +50,7 @@
 #define KEY_TITLEBAR_FONT "/apps/marco/general/titlebar_font"
 #define KEY_NUM_WORKSPACES "/apps/marco/general/num_workspaces"
 #define KEY_COMPOSITOR "/apps/marco/general/compositing_manager"
+#define KEY_COMPOSITOR_FAST_ALT_TAB "/apps/marco/general/compositing_fast_alt_tab"
 #define KEY_MATE_ACCESSIBILITY "/desktop/mate/interface/accessibility"
 
 #define KEY_COMMAND_DIRECTORY "/apps/marco/keybinding_commands"
@@ -81,6 +82,7 @@ static MetaFocusNewWindows focus_new_windows = META_FOCUS_NEW_WINDOWS_SMART;
 static gboolean raise_on_click = TRUE;
 static char* current_theme = NULL;
 static int num_workspaces = 4;
+static MetaWrapStyle wrap_style = META_WRAP_NONE;
 static MetaActionTitlebar action_double_click_titlebar = META_ACTION_TITLEBAR_TOGGLE_MAXIMIZE;
 static MetaActionTitlebar action_middle_click_titlebar = META_ACTION_TITLEBAR_LOWER;
 static MetaActionTitlebar action_right_click_titlebar = META_ACTION_TITLEBAR_MENU;
@@ -96,6 +98,7 @@ static gboolean mate_animations = TRUE;
 static char *cursor_theme = NULL;
 static int   cursor_size = 24;
 static gboolean compositing_manager = FALSE;
+static gboolean compositing_fast_alt_tab = FALSE;
 static gboolean resize_with_right_button = FALSE;
 static gboolean force_fullscreen = TRUE;
 
@@ -188,6 +191,14 @@ static MateConfEnumStringPair symtab_focus_new_windows[] =
     { 0, NULL },
   };
 
+static MateConfEnumStringPair symtab_wrap_style[] =
+  {
+    { META_WRAP_NONE,     "no wrap" },
+    { META_WRAP_CLASSIC,  "classic" },
+    { META_WRAP_TOROIDAL, "toroidal" },
+    { 0, NULL },
+  };
+
 static MateConfEnumStringPair symtab_visual_bell_type[] =
   {
     /* Note to the reader: 0 is an invalid value; these start at 1. */
@@ -327,6 +338,11 @@ static MetaEnumPreference preferences_enum[] =
       symtab_focus_mode,
       &focus_mode,
     },
+    { "/apps/marco/general/wrap_style",
+      META_PREF_WRAP_STYLE,
+      symtab_wrap_style,
+      &wrap_style,
+    },
     { "/apps/marco/general/visual_bell_type",
       META_PREF_VISUAL_BELL_TYPE,
       symtab_visual_bell_type,
@@ -407,6 +423,11 @@ static MetaBoolPreference preferences_bool[] =
       &compositing_manager,
       FALSE,
     },
+    { "/apps/marco/general/compositing_fast_alt_tab",
+      META_PREF_COMPOSITING_FAST_ALT_TAB,
+      &compositing_fast_alt_tab,
+      FALSE,
+    },
     { "/apps/marco/general/resize_with_right_button",
       META_PREF_RESIZE_WITH_RIGHT_BUTTON,
       &resize_with_right_button,
@@ -1642,6 +1663,12 @@ meta_prefs_get_num_workspaces (void)
   return num_workspaces;
 }
 
+MetaWrapStyle
+meta_prefs_get_wrap_style (void)
+{
+  return wrap_style;
+}
+
 gboolean
 meta_prefs_get_application_based (void)
 {
@@ -1679,7 +1706,7 @@ meta_preference_to_string (MetaPreference pref)
 
     case META_PREF_RAISE_ON_CLICK:
       return "RAISE_ON_CLICK";
-      
+
     case META_PREF_THEME:
       return "THEME";
 
@@ -1689,6 +1716,9 @@ meta_preference_to_string (MetaPreference pref)
     case META_PREF_NUM_WORKSPACES:
       return "NUM_WORKSPACES";
 
+    case META_PREF_WRAP_STYLE:
+      return "WRAP_STYLE";
+
     case META_PREF_APPLICATION_BASED:
       return "APPLICATION_BASED";
 
@@ -1752,6 +1782,9 @@ meta_preference_to_string (MetaPreference pref)
     case META_PREF_COMPOSITING_MANAGER:
       return "COMPOSITING_MANAGER";
 
+    case META_PREF_COMPOSITING_FAST_ALT_TAB:
+      return "COMPOSITING_FAST_ALT_TAB";
+
     case META_PREF_RESIZE_WITH_RIGHT_BUTTON:
       return "RESIZE_WITH_RIGHT_BUTTON";
 
@@ -2707,6 +2740,12 @@ meta_prefs_get_compositing_manager (void)
   return compositing_manager;
 }
 
+gboolean
+meta_prefs_get_compositing_fast_alt_tab(void)
+{
+    return compositing_fast_alt_tab;
+}
+
 guint
 meta_prefs_get_mouse_button_resize (void)
 {
@@ -2747,6 +2786,28 @@ meta_prefs_set_compositing_manager (gboolean whether)
 #endif
 }
 
+void
+meta_prefs_set_compositing_fast_alt_tab(gboolean whether)
+{
+#ifdef HAVE_MATECONF
+    GError *err = NULL;
+
+    mateconf_client_set_bool (default_client,
+                            KEY_COMPOSITOR_FAST_ALT_TAB,
+                            whether,
+                            &err);
+    
+    if (err)
+    {
+        meta_warning (_("Error setting compositor fast alt-tab status: %s\n"),
+                      err->message);
+        g_error_free (err);
+    }
+#else
+    compositing_fast_alt_tab = whether;
+#endif
+}
+
 #ifndef HAVE_MATECONF
 static void
 init_button_layout(void)
